@@ -40,8 +40,8 @@ def grab_with_vid_pid(vid, pid):
     for p in ports:
         if p.vid == vid and p.pid == pid:
             return p.device
-        else:
-            raise RuntimeError(f"Could not find serial port with the vid:pid {vid}{pid}.")
+
+    raise RuntimeError(f"Could not find serial port with the vid:pid {vid}{pid}.")
 
 
 def grab_with_description(description, exact_match=False):
@@ -51,13 +51,12 @@ def grab_with_description(description, exact_match=False):
         if exact_match is False:
             if description in p.description:
                 return p.device
-            else:
-                raise RuntimeError(f"Could not find serial port with {description} in the description.")
+
         else:
             if description == p.description:
                 return p.device
-            else:
-                raise RuntimeError(f"Could not find serial port with the exact description {description}")
+
+    raise RuntimeError(f"Could not find serial port with the exact description {description}")
 
 
 def grab_with_serial_number(serial_number):
@@ -66,5 +65,5 @@ def grab_with_serial_number(serial_number):
     for p in ports:
         if p.serial_number == serial_number:
             return p.device
-        else:
-            raise RuntimeError(f"Could not find serial port with the serial_number {serial_number}.")
\ No newline at end of file
+
+    raise RuntimeError(f"Could not find serial port with the serial_number {serial_number}.")
\ No newline at end of file
